CountryRules class abstract

Interface for country-specific validation rules.

Implementers

Constructors

CountryRules()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postalCode(String? value) String?
Validates the postal code for a specific country.
stateOrProvince(String? value) String?
Validates the state or province for a specific country.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(String countryCode) CountryRules
Returns the CountryRules for the given ISO 3166-1 alpha-2 countryCode (case-insensitive), e.g. 'US', 'CA', 'GB'.