GermanyRules class

Validation rules specifically for Germany.

Implemented types

Constructors

GermanyRules()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postalCode(String? value) String?
Validates the postal code for a specific country.
override
stateOrProvince(String? value) String?
Validates the state or province for a specific country.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited